{
    "$graph": [
        {
            "class": "Workflow",
            "label": "scRNA-seq pipeline using Salmon and Alevin",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "label": "scRNA-seq assay",
                    "type": "string",
                    "id": "#main/assay"
                },
                {
                    "label": "Directory containing FASTQ files",
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "id": "#main/fastq_dir"
                },
                {
                    "label": "Number of threads for Salmon",
                    "type": "int",
                    "default": 1,
                    "id": "#main/threads"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#main/assay",
                            "id": "#main/adjust_barcodes/assay"
                        },
                        {
                            "source": "#main/fastq_dir",
                            "id": "#main/adjust_barcodes/fastq_dir"
                        }
                    ],
                    "out": [
                        "#main/adjust_barcodes/adj_fastq_dir",
                        "#main/adjust_barcodes/metadata_json"
                    ],
                    "run": "#adjust-barcodes.cwl",
                    "id": "#main/adjust_barcodes"
                },
                {
                    "in": [
                        {
                            "source": "#main/salmon/output_dir",
                            "id": "#main/alevin_to_anndata/alevin_dir"
                        }
                    ],
                    "out": [
                        "#main/alevin_to_anndata/expr_h5ad",
                        "#main/alevin_to_anndata/raw_expr_h5ad"
                    ],
                    "run": "#alevin-to-anndata.cwl",
                    "label": "Convert Alevin output to AnnData object in h5ad format",
                    "id": "#main/alevin_to_anndata"
                },
                {
                    "in": [
                        {
                            "source": "#main/assay",
                            "id": "#main/annotate_cells/assay"
                        },
                        {
                            "source": "#main/alevin_to_anndata/expr_h5ad",
                            "id": "#main/annotate_cells/h5ad_file"
                        },
                        {
                            "source": "#main/adjust_barcodes/metadata_json",
                            "id": "#main/annotate_cells/metadata_json"
                        },
                        {
                            "source": "#main/fastq_dir",
                            "id": "#main/annotate_cells/orig_fastq_dirs"
                        }
                    ],
                    "out": [
                        "#main/annotate_cells/annotated_h5ad_file",
                        "#main/annotate_cells/annotated_zarr_dir"
                    ],
                    "run": "#annotate-cells.cwl",
                    "id": "#main/annotate_cells"
                },
                {
                    "scatter": [
                        "#main/fastqc/fastq_dir"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/fastq_dir",
                            "id": "#main/fastqc/fastq_dir"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/fastqc/threads"
                        }
                    ],
                    "out": [
                        "#main/fastqc/fastqc_dir"
                    ],
                    "run": "#fastqc.cwl",
                    "label": "Run fastqc on all fastq files in fastq directory",
                    "id": "#main/fastqc"
                },
                {
                    "in": [
                        {
                            "source": "#main/adjust_barcodes/adj_fastq_dir",
                            "id": "#main/salmon/adj_fastq_dir"
                        },
                        {
                            "source": "#main/assay",
                            "id": "#main/salmon/assay"
                        },
                        {
                            "source": "#main/fastq_dir",
                            "id": "#main/salmon/orig_fastq_dirs"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/salmon/threads"
                        }
                    ],
                    "out": [
                        "#main/salmon/output_dir"
                    ],
                    "run": "#salmon.cwl",
                    "label": "Salmon Alevin, with index from GRCh38 transcriptome",
                    "id": "#main/salmon"
                },
                {
                    "in": [
                        {
                            "source": "#main/assay",
                            "id": "#main/scanpy_analysis/assay"
                        },
                        {
                            "source": "#main/annotate_cells/annotated_h5ad_file",
                            "id": "#main/scanpy_analysis/h5ad_file"
                        }
                    ],
                    "out": [
                        "#main/scanpy_analysis/qc_results",
                        "#main/scanpy_analysis/filtered_data_h5ad",
                        "#main/scanpy_analysis/filtered_data_zarr",
                        "#main/scanpy_analysis/umap_plot",
                        "#main/scanpy_analysis/marker_gene_plot_t_test",
                        "#main/scanpy_analysis/marker_gene_plot_logreg",
                        "#main/scanpy_analysis/dispersion_plot",
                        "#main/scanpy_analysis/umap_density_plot",
                        "#main/scanpy_analysis/slideseq_plot"
                    ],
                    "run": "#scanpy-analysis.cwl",
                    "label": "Secondary analysis via ScanPy",
                    "id": "#main/scanpy_analysis"
                },
                {
                    "in": [
                        {
                            "source": "#main/annotate_cells/annotated_h5ad_file",
                            "id": "#main/scvelo_analysis/spliced_h5ad_file"
                        }
                    ],
                    "out": [
                        "#main/scvelo_analysis/annotated_h5ad_file",
                        "#main/scvelo_analysis/annotated_zarr_dir",
                        "#main/scvelo_analysis/embedding_grid_plot",
                        "#main/scvelo_analysis/embedding_stream_plot"
                    ],
                    "run": "#scvelo-analysis.cwl",
                    "label": "RNA velocity analysis via scVelo",
                    "id": "#main/scvelo_analysis"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "outputSource": "#main/annotate_cells/annotated_h5ad_file",
                    "type": "File",
                    "label": "Unfiltered count matrix from Alevin, converted to H5AD, spliced and unspliced counts",
                    "id": "#main/count_matrix_h5ad"
                },
                {
                    "outputSource": "#main/annotate_cells/annotated_zarr_dir",
                    "type": "Directory",
                    "label": "Unfiltered count matrix from Alevin, converted to H5AD, spliced and unspliced counts",
                    "id": "#main/count_matrix_zarr"
                },
                {
                    "outputSource": "#main/scanpy_analysis/dispersion_plot",
                    "type": "File",
                    "label": "Gene expression dispersion plot",
                    "id": "#main/dispersion_plot"
                },
                {
                    "outputSource": "#main/fastqc/fastqc_dir",
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "label": "Directory of FastQC output files, mirroring input directory structure",
                    "id": "#main/fastqc_dir"
                },
                {
                    "outputSource": "#main/scanpy_analysis/filtered_data_h5ad",
                    "type": "File",
                    "label": "Full data set of filtered results",
                    "doc": "Full data set of filtered results: expression matrix, coordinates in dimensionality-reduced space (PCA and UMAP), cluster assignments via the Leiden algorithm, and marker genes for one cluster vs. rest",
                    "id": "#main/filtered_data_h5ad"
                },
                {
                    "outputSource": "#main/scanpy_analysis/filtered_data_zarr",
                    "type": "Directory",
                    "label": "Full data set of filtered results",
                    "doc": "Full data set of filtered results: expression matrix, coordinates in dimensionality-reduced space (PCA and UMAP), cluster assignments via the Leiden algorithm, and marker genes for one cluster vs. rest",
                    "id": "#main/filtered_data_zarr"
                },
                {
                    "outputSource": "#main/scanpy_analysis/marker_gene_plot_logreg",
                    "type": "File",
                    "label": "Cluster marker genes, logreg method",
                    "id": "#main/marker_gene_plot_logreg"
                },
                {
                    "outputSource": "#main/scanpy_analysis/marker_gene_plot_t_test",
                    "type": "File",
                    "label": "Cluster marker genes, t-test",
                    "id": "#main/marker_gene_plot_t_test"
                },
                {
                    "outputSource": "#main/scanpy_analysis/qc_results",
                    "type": "File",
                    "label": "Quality control metrics",
                    "id": "#main/qc_results"
                },
                {
                    "outputSource": "#main/alevin_to_anndata/raw_expr_h5ad",
                    "type": "File",
                    "label": "Unfiltered count matrix from Alevin, converted to H5AD, with intronic regions",
                    "id": "#main/raw_count_matrix"
                },
                {
                    "outputSource": "#main/salmon/output_dir",
                    "type": "Directory",
                    "label": "Full output of `salmon alevin`",
                    "id": "#main/salmon_output"
                },
                {
                    "outputSource": "#main/scvelo_analysis/annotated_h5ad_file",
                    "type": "File",
                    "label": "scVelo-annotated h5ad file, including cell RNA velocity",
                    "id": "#main/scvelo_annotated_h5ad"
                },
                {
                    "outputSource": "#main/scvelo_analysis/annotated_zarr_dir",
                    "type": "Directory",
                    "label": "scVelo-annotated zarr directory, including cell RNA velocity",
                    "id": "#main/scvelo_annotated_zarr"
                },
                {
                    "outputSource": "#main/scvelo_analysis/embedding_grid_plot",
                    "type": "File",
                    "label": "scVelo velocity embedding grid plot",
                    "id": "#main/scvelo_embedding_grid_plot"
                },
                {
                    "outputSource": "#main/scvelo_analysis/embedding_stream_plot",
                    "type": [
                        "null",
                        "File"
                    ],
                    "label": "scVelo velocity embedding stream plot",
                    "id": "#main/scvelo_embedding_stream_plot"
                },
                {
                    "outputSource": "#main/scanpy_analysis/slideseq_plot",
                    "type": [
                        "null",
                        "File"
                    ],
                    "label": "Slide-seq bead plot, colored by Leiden cluster",
                    "id": "#main/slideseq_plot"
                },
                {
                    "outputSource": "#main/scanpy_analysis/umap_density_plot",
                    "type": "File",
                    "label": "UMAP dimensionality reduction plot, colored by cell density",
                    "id": "#main/umap_density_plot"
                },
                {
                    "outputSource": "#main/scanpy_analysis/umap_plot",
                    "type": "File",
                    "label": "UMAP dimensionality reduction plot",
                    "id": "#main/umap_plot"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Assay-specific adjustment of cell barcodes",
            "hints": [
                {
                    "dockerPull": "hubmap/scrna-barcode-adj:2.0.4",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "/opt/adjust_barcodes.py",
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 0
                    },
                    "id": "#adjust-barcodes.cwl/assay"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#adjust-barcodes.cwl/fastq_dir"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "adj_fastq"
                    },
                    "id": "#adjust-barcodes.cwl/adj_fastq_dir"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "metadata.json"
                    },
                    "id": "#adjust-barcodes.cwl/metadata_json"
                }
            ],
            "id": "#adjust-barcodes.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Convert Alevin sparse output to anndata.AnnData object, save as h5ad",
            "hints": [
                {
                    "dockerPull": "hubmap/scrna-analysis:2.0.4",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "/opt/alevin_to_anndata.py",
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#alevin-to-anndata.cwl/alevin_dir"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "expr.h5ad"
                    },
                    "id": "#alevin-to-anndata.cwl/expr_h5ad"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "raw_expr.h5ad"
                    },
                    "id": "#alevin-to-anndata.cwl/raw_expr_h5ad"
                }
            ],
            "id": "#alevin-to-anndata.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Assay-specific annotation of cell barcodes after quantification",
            "hints": [
                {
                    "dockerPull": "hubmap/scrna-analysis:2.0.4",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "/opt/annotate_cells.py",
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 0
                    },
                    "id": "#annotate-cells.cwl/assay"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#annotate-cells.cwl/h5ad_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--metadata_json"
                    },
                    "id": "#annotate-cells.cwl/metadata_json"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#annotate-cells.cwl/orig_fastq_dirs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "expr.h5ad"
                    },
                    "id": "#annotate-cells.cwl/annotated_h5ad_file"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "expr.zarr"
                    },
                    "id": "#annotate-cells.cwl/annotated_zarr_dir"
                }
            ],
            "id": "#annotate-cells.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Runs fastQC on each fastq file in fastq directory",
            "hints": [
                {
                    "dockerPull": "hubmap/scrna-analysis:2.0.4",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "/opt/fastqc_wrapper.py",
            "inputs": [
                {
                    "type": "Directory",
                    "doc": "Directory containing fastq files to be evaluated",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#fastqc.cwl/fastq_dir"
                },
                {
                    "type": "int",
                    "doc": "The number of threads to use for fastqc",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#fastqc.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "fastqc_output"
                    },
                    "doc": "Individual graph files and additional data files containing the raw data from which plots were drawn.",
                    "id": "#fastqc.cwl/fastqc_dir"
                }
            ],
            "id": "#fastqc.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "hubmap/salmon-grch38:2.0.4",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "/opt/salmon_wrapper.py",
            "label": "Run Salmon Alevin tool on FASTQ input",
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#salmon.cwl/adj_fastq_dir"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 0
                    },
                    "id": "#salmon.cwl/assay"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#salmon.cwl/orig_fastq_dirs"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--threads"
                    },
                    "id": "#salmon.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "salmon_out"
                    },
                    "id": "#salmon.cwl/output_dir"
                }
            ],
            "id": "#salmon.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Dimensionality reduction and clustering",
            "hints": [
                {
                    "dockerPull": "hubmap/scrna-analysis:2.0.4",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "/opt/scanpy_entry_point.py",
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 0
                    },
                    "id": "#scanpy-analysis.cwl/assay"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#scanpy-analysis.cwl/h5ad_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "dispersion_plot.pdf"
                    },
                    "id": "#scanpy-analysis.cwl/dispersion_plot"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "secondary_analysis.h5ad"
                    },
                    "id": "#scanpy-analysis.cwl/filtered_data_h5ad"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "secondary_analysis.zarr"
                    },
                    "id": "#scanpy-analysis.cwl/filtered_data_zarr"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "marker_genes_by_cluster_logreg.pdf"
                    },
                    "id": "#scanpy-analysis.cwl/marker_gene_plot_logreg"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "marker_genes_by_cluster_t_test.pdf"
                    },
                    "id": "#scanpy-analysis.cwl/marker_gene_plot_t_test"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "qc_results.hdf5"
                    },
                    "id": "#scanpy-analysis.cwl/qc_results"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "spatial_pos_by_leiden_cluster.pdf"
                    },
                    "id": "#scanpy-analysis.cwl/slideseq_plot"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "umap_embedding_density.pdf"
                    },
                    "id": "#scanpy-analysis.cwl/umap_density_plot"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "umap_by_leiden_cluster.pdf"
                    },
                    "id": "#scanpy-analysis.cwl/umap_plot"
                }
            ],
            "id": "#scanpy-analysis.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "RNA velocity analysis via scVelo",
            "hints": [
                {
                    "dockerPull": "hubmap/scrna-analysis:2.0.4",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "/opt/scvelo_analysis.py",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#scvelo-analysis.cwl/spliced_h5ad_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "scvelo_annotated.h5ad"
                    },
                    "id": "#scvelo-analysis.cwl/annotated_h5ad_file"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "scvelo_annotated.zarr"
                    },
                    "id": "#scvelo-analysis.cwl/annotated_zarr_dir"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "scvelo_embedding_grid.pdf"
                    },
                    "id": "#scvelo-analysis.cwl/embedding_grid_plot"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "scvelo_embedding_stream.pdf"
                    },
                    "id": "#scvelo-analysis.cwl/embedding_stream_plot"
                }
            ],
            "id": "#scvelo-analysis.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
